{ pkgs, lib, ... }:
let
  opentofu = pkgs.opentofu;
  bw-opentofu = lib.khscodes.mkBwEnv {
    inherit pkgs;
    name = "bw-opentofu";
    items = {
      "KHS Openstack" = {
        TF_VAR_openstack_username = "login.username";
        TF_VAR_openstack_password = "login.password";
        TF_VAR_openstack_tenant_name = "Project Name";
        TF_VAR_openstack_auth_url = "Auth URL";
        TF_VAR_openstack_endpoint_type = "Interface";
        TF_VAR_openstack_region = "Region Name";
      };
      "Cloudflare" = {
        TF_VAR_cloudflare_token = "DNS API Token";
        TF_VAR_cloudflare_email = "login.username";
        AWS_ACCESS_KEY_ID = "BW Terraform access key id";
        AWS_SECRET_ACCESS_KEY = "BW Terraform secret access key";
      };
      "Hetzner Cloud" = {
        TF_VAR_hcloud_api_token = "Terraform API Token";
      };
    };
    exe = lib.getExe opentofu;
  };
in
pkgs.writeShellApplication {
  name = "bw-opentofu";
  runtimeInputs = [
    bw-opentofu
    pkgs.uutils-coreutils-noprefix
    pkgs.bitwarden-cli
  ];
  text = ''
    fqdn="$1"
    config="$2"
    lockHcl="$3"
    dir="$(mktemp -d --tmpdir -t "terraform-hetzher-''${fqdn}.XXXXXXXXXX")"
    cp "$lockHcl" "$dir/.terraform.lock.hcl"
    cp "''${config}" "$dir/config.tf.json"
    if [ "''${BW_SESSION:-}" == "" ]; then
      BW_SESSION="$(bw unlock --raw)"
      export BW_SESSION
      trap "bw lock" EXIT
    fi
    bw-opentofu -chdir="$dir" init
    bw-opentofu -chdir="$dir" apply
  '';
}
